lenstest
=========

.. image:: https://colab.research.google.com/assets/colab-badge.svg
   :target: https://colab.research.google.com/github/scottprahl/lenstest/blob/master

.. image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/scottprahl/lenstest/master?filepath=docs

.. image:: https://img.shields.io/badge/readthedocs-latest-blue.svg
   :target: https://lenstest.readthedocs.io

.. image:: https://img.shields.io/badge/github-code-green.svg
   :target: https://github.com/scottprahl/lenstest

.. image:: https://img.shields.io/badge/MIT-license-yellow.svg
   :target: https://github.com/scottprahl/lenstest/blob/master/LICENSE.txt

__________

A collection of routines for non-interferometric testing of lenses and mirrors.

This implementation contains code for

    * Foucault Knife Edge Test
    * Ronchi Ruling Test

Using lenstest
-------------------

1. Install with ``pip``::
    
    pip install --user lenstest

2. or `run this code in the cloud using Google Collaboratory <https://colab.research.google.com/github/scottprahl/lenstest/blob/master>`_ by selecting the Jupyter notebook that interests you.

3. use `binder <https://mybinder.org/v2/gh/scottprahl/lenstest/master?filepath=docs>`_ which will create a new environment that allows you to run Jupyter notebooks.  This takes a bit longer to start, but it automatically installs ``lenstest``.

4. clone the `lenstest github repository <https://github.com/scottprahl/lenstest>`_ and then add the repository to your ``PYTHONPATH`` environment variable


License
-------

lenstest is licensed under the terms of the MIT license.